@@ -587,7 +587,8 @@ gs_updates_page_get_upgrades_cb (GObject *source_object,
 		gs_updates_page_clear_flag (self, GS_UPDATES_PAGE_FLAG_HAS_UPGRADES);
 		gtk_widget_set_visible (self->upgrade_banner, FALSE);
 	} else {
-		/* rely on the app list already being sorted */
+		/* rely on the app list already being sorted with the
+		 * chronologically newest release last */
 		GsApp *app = gs_app_list_index (list, gs_app_list_length (list) - 1);
 		g_debug ("got upgrade %s", gs_app_get_id (app));
 		gs_upgrade_banner_set_app (GS_UPGRADE_BANNER (self->upgrade_banner), app);
@@ -1248,8 +1249,9 @@ gs_updates_page_status_changed_cb (GsPluginLoader *plugin_loader,
 	switch (status) {
 	case GS_PLUGIN_STATUS_INSTALLING:
 	case GS_PLUGIN_STATUS_REMOVING:
-		if (gs_app_get_kind (app) != AS_APP_KIND_OS_UPGRADE &&
-		    gs_app_get_id (app) != NULL) {
+		if (app == NULL ||
+		    (gs_app_get_kind (app) != AS_APP_KIND_OS_UPGRADE &&
+		     gs_app_get_id (app) != NULL)) {
 			/* if we do a install or remove then make sure all new
 			 * packages are downloaded */
 			gs_updates_page_invalidate_downloaded_upgrade (self);
