@@ -274,13 +274,11 @@ _perform_update_cb (GsPluginLoader *plugin_loader, GAsyncResult *res, gpointer u
 	g_autoptr(GsUpdatesSectionUpdateHelper) helper = (GsUpdatesSectionUpdateHelper *) user_data;
 	GsUpdatesSection *self = helper->self;
 
-	/* a good place */
-	gs_shell_profile_dump (gs_page_get_shell (self->page));
-
 	/* get the results */
 	if (!gs_plugin_loader_job_action_finish (plugin_loader, res, &error)) {
-		g_warning ("failed to perform update: %s", error->message);
-		return;
+		if (!g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
+			g_warning ("failed to perform update: %s", error->message);
+		goto out;
 	}
 
 	/* trigger reboot if any application was not updatable live */
@@ -313,6 +311,8 @@ _perform_update_cb (GsPluginLoader *plugin_loader, GAsyncResult *res, gpointer u
 		g_notification_set_priority (n, G_NOTIFICATION_PRIORITY_URGENT);
 		g_application_send_notification (g_application_get_default (), "restart-required", n);
 	}
+
+out:
 	g_clear_object (&self->cancellable);
 	_update_buttons (self);
 }
@@ -324,6 +324,21 @@ _button_cancel_clicked_cb (GtkButton *button, GsUpdatesSection *self)
 	_update_buttons (self);
 }
 
+static GsAppList *
+_get_listbox_apps (GsUpdatesSection *self)
+{
+	g_autoptr(GsAppList) apps = gs_app_list_new ();
+	g_autoptr(GList) listbox_children = NULL;
+
+	listbox_children = gtk_container_get_children (GTK_CONTAINER (self));
+	for (GList *l = listbox_children; l; l = l->next) {
+		GsAppRow *app_row = GS_APP_ROW (l->data);
+		gs_app_list_add (apps, gs_app_row_get_app (app_row));
+	}
+
+	return g_steal_pointer (&apps);
+}
+
 static void
 _button_update_all_clicked_cb (GtkButton *button, GsUpdatesSection *self)
 {
@@ -331,13 +346,18 @@ _button_update_all_clicked_cb (GtkButton *button, GsUpdatesSection *self)
 	g_autoptr(GCancellable) cancellable = g_cancellable_new ();
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 	GsUpdatesSectionUpdateHelper *helper = g_new0 (GsUpdatesSectionUpdateHelper, 1);
+	g_autoptr(GsAppList) sorted_list = NULL;
+
+	/* instead of using self->list, get the already-sorted apps back from
+	 * the listbox to be able to update them in display order */
+	sorted_list = _get_listbox_apps (self);
 
 	helper->self = g_object_ref (self);
 
 	/* look at each app in turn */
-	for (guint i = 0; i < gs_app_list_length (self->list); i++) {
-		GsApp *app = gs_app_list_index (self->list, i);
-		if (gs_app_get_state (app) != AS_APP_STATE_UPDATABLE_LIVE)
+	for (guint i = 0; i < gs_app_list_length (sorted_list); i++) {
+		GsApp *app = gs_app_list_index (sorted_list, i);
+		if (gs_app_get_state (app) == AS_APP_STATE_UPDATABLE)
 			helper->do_reboot = TRUE;
 		if (gs_app_has_quirk (app, AS_APP_QUIRK_NEEDS_REBOOT))
 			helper->do_reboot_notification = TRUE;
@@ -345,7 +365,7 @@ _button_update_all_clicked_cb (GtkButton *button, GsUpdatesSection *self)
 
 	g_set_object (&self->cancellable, cancellable);
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_UPDATE,
-					 "list", self->list,
+					 "list", sorted_list,
 					 "interactive", TRUE,
 					 NULL);
 	gs_plugin_loader_job_process_async (self->plugin_loader, plugin_job,
